==> kadu_0.11.0.orig.tar.bz2: kadu-0.11.0/plugins/sms/translations/sms_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>Pseudonim SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Używaj wbudowanej aplikacji SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Własna aplikacja SMS</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Używaj własnych argumentów SMS</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Argumenty SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Bramki</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Bramka SMS T-Mobile.pl</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponsorowana</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>Orange Multibox</source>
        <translation>Orange Multibox</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>ID użytkownika (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation>Zaznacz to pole, jeśli twoja aplikacja sms nie przyjmuje argumentów: numer &amp;wiadomość&amp;
Argumenty powinny być rozdzielone spacjami. Argument %k jest traktowany jak numer, %m jako wiadomość</translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation>Proxy dla wbudowanej aplikacji SMS</translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Wyślij SMS-a...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Odbiorca</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Wybierz automatycznie</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Operator GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Treść</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Zapisz SMS w historii</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Wyślij</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Nie określono aplikacji SMS. Sprawdź konfigurację</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Problem z uruchomieniem programu do wysyłania SMS</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces zakończony nieprawidłowo. SMS mógł nie zostać wysłany</translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Przepisz tekst z obrazka:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>Unable to fetch required token</source>
        <translation>Nie udało się pobrać wymaganego tokena</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation>Pole &quot;Podpis&quot; nie może być puste</translation>
    </message>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatyczny wybór bramki jest niedostępny. Proszę wybierz bramkę SMS.</translation>
    </message>
</context>
<context>
    <name>SmsProgressWindow</name>
    <message>
        <source>Sending SMS in progress.</source>
        <translation>Trwa wysyłanie SMS-a.</translation>
    </message>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Przepisz tekst z obrazka:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>SMS sent successfully</source>
        <translation>SMS został pomyślnie wysłany</translation>
    </message>
</context>
</TS>

==> kadu-0.12.1.tar.bz2: kadu-0.12.1/plugins/sms/translations/sms_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>Pseudonim SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Używaj wbudowanej aplikacji SMS</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Własna aplikacja SMS</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Używaj własnych argumentów SMS</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Argumenty SMS</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>Bramki</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Bramka SMS T-Mobile.pl</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Sponsorowana</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>ID użytkownika (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation>Zaznacz to pole, jeśli twoja aplikacja sms nie przyjmuje argumentów: numer &amp;wiadomość&amp;
Argumenty powinny być rozdzielone spacjami. Argument %k jest traktowany jak numer, %m jako wiadomość</translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation>Proxy dla wbudowanej aplikacji SMS</translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Wyślij SMS-a...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Wyślij SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Odbiorca</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Wybierz automatycznie</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Operator GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Treść</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Podpis</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>Zapisz SMS w historii</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Wyślij</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Nie określono aplikacji SMS. Sprawdź konfigurację</translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation> - Wybierz odbiorcę - </translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Wysyłanie wiadomości SMS...</translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Problem z uruchomieniem programu do wysyłania SMS</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Proces zakończony nieprawidłowo. SMS mógł nie zostać wysłany</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>SMS wysłany</translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatyczny wybór bramki jest niedostępny. Proszę wybierz bramkę SMS.</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation>Podpis nie może być pusty.</translation>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation>Wykrywanie bramki...</translation>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation>Wykryto bramknę: %1.</translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation>Wysyłanie wiadomości SMS...</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>SMS wysłany</translation>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation>Niepoprawny parametr dla zadania odczytu tokena.</translation>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation>Pobieranie obrazka tokena...</translation>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation>Nie można pobrać obrazka tokena.</translation>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation>Nie można przeczytać obrazka tokena.</translation>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation>Oczekiwanie na wporwadzenie wartości tokena...</translation>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation>Wartość tokena nie została wprowadzona.</translation>
    </message>
    <message>
        <source>Received token value.</source>
        <translation>Otrzymano wartość tokena.</translation>
    </message>
</context>
</TS>
